@@ -288,7 +288,7 @@ where
     pub fn get_account_info(&self, address: &AccountId) -> ApiResult<Option<AccountInfo>> {
         let storagekey: sp_core::storage::StorageKey =
             self.metadata
-                .storage_map_key::<AccountId>("System", "Account", address.clone())?;
+                .storage_map_key("System", "Account", address.encode())?;
         info!("storagekey {:?}", storagekey);
         info!("storage key is: 0x{}", hex::encode(storagekey.0.clone()));
         let info = self.get_storage_by_key_hash(storagekey, None)?;
@@ -362,16 +362,16 @@ where
         self.get_storage_by_key_hash(storagekey, at_block)
     }
 
-    pub fn get_storage_map<K: Encode>(
+    pub fn get_storage_map(
         &self,
         storage_prefix: &str,
         storage_key_name: &str,
-        map_key: K,
+        map_key: Vec<u8>,
         at_block: Option<Hash>,
     ) -> ApiResult<Option<StorageValue>> {
         let storagekey =
             self.metadata
-                .storage_map_key::<K>(storage_prefix, storage_key_name, map_key)?;
+                .storage_map_key(storage_prefix, storage_key_name, map_key)?;
         info!("storage key is: 0x{}", hex::encode(storagekey.0.clone()));
         self.get_storage_by_key_hash(storagekey, at_block)
     }
@@ -386,15 +386,15 @@ where
             .map_err(|e| e.into())
     }
 
-    pub fn get_storage_double_map<K: Encode, Q: Encode>(
+    pub fn get_storage_double_map(
         &self,
         storage_prefix: &str,
         storage_key_name: &str,
-        first: K,
-        second: Q,
+        first: Vec<u8>,
+        second: Vec<u8>,
         at_block: Option<Hash>,
     ) -> ApiResult<Option<StorageValue>> {
-        let storagekey = self.metadata.storage_double_map_key::<K, Q>(
+        let storagekey = self.metadata.storage_double_map_key(
             storage_prefix,
             storage_key_name,
             first,
@@ -443,29 +443,29 @@ where
         self.get_storage_proof_by_keys(vec![storagekey], at_block)
     }
 
-    pub fn get_storage_map_proof<K: Encode, V: Decode + Clone>(
+    pub fn get_storage_map_proof(
         &self,
         storage_prefix: &str,
         storage_key_name: &str,
-        map_key: K,
+        map_key: Vec<u8>,
         at_block: Option<Hash>,
     ) -> ApiResult<Option<ReadProof<Hash>>> {
         let storagekey =
             self.metadata
-                .storage_map_key::<K>(storage_prefix, storage_key_name, map_key)?;
+                .storage_map_key(storage_prefix, storage_key_name, map_key)?;
         info!("storage key is: 0x{}", hex::encode(storagekey.0.clone()));
         self.get_storage_proof_by_keys(vec![storagekey], at_block)
     }
 
-    pub fn get_storage_double_map_proof<K: Encode, Q: Encode, V: Decode + Clone>(
+    pub fn get_storage_double_map_proof(
         &self,
         storage_prefix: &str,
         storage_key_name: &str,
-        first: K,
-        second: Q,
+        first: Vec<u8>,
+        second: Vec<u8>,
         at_block: Option<Hash>,
     ) -> ApiResult<Option<ReadProof<Hash>>> {
-        let storagekey = self.metadata.storage_double_map_key::<K, Q>(
+        let storagekey = self.metadata.storage_double_map_key(
             storage_prefix,
             storage_key_name,
             first,
